/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
 * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     User can increase or decrease resitance by pressing buttons RB2 and RB3. It's all happening in an endless loop.
     Mesure resistace between W and H/L.
 * Test configuration:
     MCU:             dsPIC30F4013
                      http://ww1.microchip.com/downloads/en/devicedoc/70138c.pdf
     Dev.Board:       EasyPIC v7 for dsPIC30
                      http://www.mikroe.com/eng/products/view/887/easypic-v7-for-dspic-development-system/
     Oscillator:      XT-PLL 80.0000 MHz, 10.0000 MHz Crystal
     Ext. modules:    DigiPot 2 click

     SW:              mikroC PRO for dsPIC
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic/
 * NOTES:
     - DigiPot 2 click must be connected on mikroBUS socket 1.
     - Place Button Press Level switch in upper position for PORTD and
       pull down PortD pins 0 and 1 (PortD three-state switch).
     - Close port RB10 at ADC INPUT, to enable ADC on channel 10 that is used in this example (board specific).
*/

#include "built_in.h"

sbit DigPot_CS at LATB11_bit;
sbit DigPot_CS_Direction at TRISB11_bit;

unsigned int adc_value;
char counter;

void InitMain() {

  TRISB = 0xFFFF;                        // PORTB is input
  PORTD = 0x0000;
  TRISD = 0x0003;                        // Set RD0 and RD1 as input


  DigPot_CS = 1;
  DigPot_CS_Direction = 0;

  // Initialize SPI1 module
  SPI1_Init_Advanced(_SPI_MASTER, _SPI_8_BIT, _SPI_PRESCALE_SEC_5, _SPI_PRESCALE_PRI_4, _SPI_SS_DISABLE, _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_LOW, _SPI_IDLE_2_ACTIVE);

  ADC1_Init();                // Enable ADC module

  adc_value = 0;
  counter = 0;
}


void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI1_Write(0);
    SPI1_Write(counter);

    SPI1_Write(0x20);
    SPI1_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC1_Read(10);  // Get 10-bit results of AD conversion
    LATD = (unsigned char)(adc_value >> 2);

    if (RD0_bit)                         // Press RD0 to decrease resistance between W and L
      counter ++;
    if (RD1_bit)                         // Press RD1 to increase resistance between W and L
      counter --;

    Delay_ms(50);                        // Delay for debouncing

  }
}